@@ -15,7 +15,23 @@ void sub_matrix( double A[], double sub_A[], int sub[], int *p_sub, int *p )
 			sub_A[ixp + j] = A[subixp + sub[j]]; 
 	}
 }
-
+   
+// Takes symmetric matrix A (p x p) and 
+// retrieves upper part of sub_matrix B (p_sub x p_sub), dictated by vector sub
+void sub_matrix_upper( double A[], double sub_A[], int sub[], int *p_sub, int *p )
+{
+	int i, j, ixp, subixp, psub = *p_sub, pdim = *p;
+			
+	for( i = 0; i < psub; i++ )
+	{
+		ixp    = i * psub;
+		subixp = sub[i] * pdim;
+			
+		for( j = 0; j <= i; j++ )
+			sub_A[ixp + j] = A[subixp + sub[j]]; 
+	}
+}
+   
 // Takes square matrix A (p x p) and 
 // retrieves vector sub_A which is 'sub' th row of matrix A, minus 'sub' element
 // Likes A[j, -j] in R
@@ -23,7 +39,7 @@ void sub_row_mins( double A[], double sub_A[], int *sub, int *p )
 {
 	int subj = *sub, pdim = *p, subxp = subj * pdim;
 
-	memcpy( sub_A,        A + subxp,            sizeof( double ) * subj );		
+	memcpy( sub_A       , A + subxp           , sizeof( double ) * subj );		
 	memcpy( sub_A + subj, A + subxp + subj + 1, sizeof( double ) * ( pdim - subj - 1 ) );	
 }
    
@@ -54,12 +70,28 @@ void sub_rows_mins( double A[], double sub_A[], int *row, int *col, int *p )
 	}
 }
 
+// Takes square matrix A (p x p) and 
+// retrieves sub_matrix sub_A(p-2 x 2) which is sub cols of matrix A, minus two elements
+// Likes A[-(i,j), (i,j)] in R 
+void sub_cols_mins( double A[], double sub_A[], int *row, int *col, int *p )
+{	
+	int subi = *row, subj = *col, pdim = *p, p2 = pdim - 2, subixp = subi * pdim, subjxp = subj * pdim;
+
+	memcpy( sub_A           , A + subixp           , sizeof( double ) * subi );		
+	memcpy( sub_A + subi    , A + subixp + subi + 1, sizeof( double ) * ( subj - subi - 1 ) );	
+	memcpy( sub_A + subj - 1, A + subixp + subj + 1, sizeof( double ) * ( pdim - subj - 1 ) );	
+
+	memcpy( sub_A + p2           , A + subjxp           , sizeof( double ) * subi );		
+	memcpy( sub_A + p2 + subi    , A + subjxp + subi + 1, sizeof( double ) * ( subj - subi - 1 ) );	
+	memcpy( sub_A + p2 + subj - 1, A + subjxp + subj + 1, sizeof( double ) * ( pdim - subj - 1 ) );	
+}
+   
 // Takes symmatric matrix A (p x p) and 
-// retrieves A_jj, A12(1x(p-1)), A21((p-1)x1), and A22((p-1)x(p-1))
-// Like A11=A[j, j], A12=A[j, -j], and A22=A[-j, -j] in R
+// retrieves A12(1x(p-1)) and A22((p-1)x(p-1))
+// Like A12=A[j, -j], and A22=A[-j, -j] in R
 void sub_matrices1( double A[], double A12[], double A22[], int *sub, int *p )
 {
-	int i, j, ixpdim, ij, pdim = *p, p1 = pdim - 1, psub = *sub, subxp = psub * pdim;
+	int i, ixpdim, ixp1, pdim = *p, p1 = pdim - 1, psub = *sub, subxp = psub * pdim, mpsub = pdim - psub - 1;
 
 	memcpy( A12,        A + subxp,            sizeof( double ) * psub );	
 	memcpy( A12 + psub, A + subxp + psub + 1, sizeof( double ) * ( pdim - psub - 1 ) );	
@@ -67,27 +99,22 @@ void sub_matrices1( double A[], double A12[], double A22[], int *sub, int *p )
 	for( i = 0; i < psub; i++ )
 	{	
 		ixpdim = i * pdim;
+		ixp1   = i * p1;
 		
-		for( j = 0; j < psub; j++ )
-			A22[j * p1 + i] = A[ixpdim + j];
-
-		for( j = psub + 1; j < pdim; j++ )
-		{
-			ij = ixpdim + j;
-			A22[(j - 1) * p1 + i] = A[ij];
-			A22[i * p1 + j - 1]   = A[ij];
-		}
+		memcpy( A22 + ixp1       , A + ixpdim           , sizeof( double ) * psub );
+		memcpy( A22 + ixp1 + psub, A + ixpdim + psub + 1, sizeof( double ) * mpsub );
 	}
 
 	for( i = psub + 1; i < pdim; i++ )
 	{
 		ixpdim = i * pdim;
-			
-		for( j = psub + 1; j < pdim; j++ )
-			A22[(j - 1) * p1 + i - 1] = A[ixpdim + j];
+		ixp1   = ( i - 1 ) * p1;
+		
+		memcpy( A22 + ixp1       , A + ixpdim           , sizeof( double ) * psub);
+		memcpy( A22 + ixp1 + psub, A + ixpdim + psub + 1, sizeof( double ) * mpsub );
 	}
 }
-
+    
 // Takes square matrix A (p x p) and 
 // retrieves A11(2x2), A12(2x(p-2)), and A22((p-2)x(p-2))
 // Like A11=A[e, e], A12=A[e, -e], and A22=A[-e, -e] in R
@@ -147,14 +174,71 @@ void sub_matrices( double A[], double A11[], double A12[], double A22[], int *ro
 	{
 		ixp = i * pdim;
 				
-		A12[i + i - 4] = A[ixp + sub0];
-		A12[i + i - 3] = A[ixp + sub1];
+		A12[i + i - 4]     = A[ixp + sub0];
+		A12[i + i - 3]       = A[ixp + sub1];
 		
 		for( j = sub1 + 1; j < pdim; j++ )
 			A22[(j - 2) * p2 + i - 2] = A[ixp + j];
 	}
 }
    
+// Takes square matrix A (p x p) and 
+// retrieves A11_inv(2x2), A21((p-2)x2), and A22((p-2)x(p-2))
+// Like A11_inv=inv( A[e, e] ), A21=A[-e, e], and A22=A[-e, -e] in R
+void sub_matrices_inv( double A[], double A11_inv[], double A21[], double A22[], int *row, int *col, int *p )
+{
+	int i, ixp, ixp2, pdim = *p, p2 = pdim - 2, sub0 = *row, sub1 = *col;
+	int sub0xp = sub0 * pdim, sub1xp = sub1 * pdim, sub0_plus = sub0 + 1, sub1_plus = sub1 + 1;
+	
+	double a11 = A[sub0 * pdim + sub0];
+	double a12 = A[sub0 * pdim + sub1];
+	double a22 = A[sub1 * pdim + sub1];
+
+	double det_A11 = a11 * a22 - a12 * a12;
+	A11_inv[0]     = a22 / det_A11;
+	A11_inv[1]     = - a12 / det_A11;
+	A11_inv[2]     = A11_inv[1];
+	A11_inv[3]     = a11 / det_A11;
+
+	memcpy( A21           , A + sub0xp            , sizeof( double ) * sub0 );		
+	memcpy( A21 + sub0    , A + sub0xp + sub0_plus, sizeof( double ) * ( sub1 - sub0_plus ) );	
+	memcpy( A21 + sub1 - 1, A + sub0xp + sub1_plus, sizeof( double ) * ( pdim - sub1_plus ) );	
+
+	memcpy( A21 + p2           , A + sub1xp            , sizeof( double ) * sub0 );		
+	memcpy( A21 + p2 + sub0    , A + sub1xp + sub0_plus, sizeof( double ) * ( sub1 - sub0_plus ) );	
+	memcpy( A21 + p2 + sub1 - 1, A + sub1xp + sub1_plus, sizeof( double ) * ( pdim - sub1_plus ) );	
+ 
+	for( i = 0; i < sub0; i++ )
+	{	
+		ixp  = i * pdim;
+		ixp2 = i * p2;
+
+		memcpy( A22 + ixp2           , A + ixp            , sizeof( double ) * sub0 );
+		memcpy( A22 + ixp2 + sub0    , A + ixp + sub0_plus, sizeof( double ) * ( sub1 - sub0_plus ) );
+		memcpy( A22 + ixp2 + sub1 - 1, A + ixp + sub1_plus, sizeof( double ) * ( pdim - sub1_plus ) );	
+	}
+ 
+	for( i = sub0_plus; i < sub1; i++ )
+	{
+		ixp  = i * pdim;
+		ixp2 = ( i - 1 ) * p2;
+
+		memcpy( A22 + ixp2           , A + ixp            , sizeof( double ) * sub0 );
+		memcpy( A22 + ixp2 + sub0    , A + ixp + sub0_plus, sizeof( double ) * ( sub1 - sub0_plus ) );
+		memcpy( A22 + ixp2 + sub1 - 1, A + ixp + sub1_plus, sizeof( double ) * ( pdim - sub1_plus ) );	
+	}
+	
+	for( i = sub1_plus; i < pdim; i++ )
+	{
+		ixp  = i * pdim;
+		ixp2 = ( i - 2 ) * p2;
+				
+		memcpy( A22 + ixp2           , A + ixp            , sizeof( double ) * sub0 );
+		memcpy( A22 + ixp2 + sub0    , A + ixp + sub0_plus, sizeof( double ) * ( sub1 - sub0_plus ) );
+		memcpy( A22 + ixp2 + sub1 - 1, A + ixp + sub1_plus, sizeof( double ) * ( pdim - sub1_plus ) );		
+	}
+}
+      
 // inverse function for symmetric positive-definite matrices (p x p)
 // WARNING: Matrix you pass is overwritten with the result
 void inverse( double A[], double A_inv[], int *p )
@@ -217,10 +301,8 @@ void select_edge( long double rates[], int *index_selected_edge, long double *su
 
 	while( upper_bound - lower_bound > 1 )
 	{
-		if ( rates[position] > random_value )    
-			upper_bound = position;    
-		else                                                
-			lower_bound = position;     
+		//if ( rates[position] > random_value ) { upper_bound = position; } else { lower_bound = position; }     
+		( rates[position] > random_value ) ? upper_bound = position : lower_bound = position;     
 		
 		position = ( lower_bound + upper_bound ) / 2;
 	}
@@ -249,10 +331,8 @@ void select_multi_edges( long double rates[], int index_selected_edges[], int *s
 
 	while( upper_bound - lower_bound > 1 )
 	{
-		if ( rates[position] > random_value )    
-			upper_bound = position;    
-		else                                                
-			lower_bound = position;     
+		//if ( rates[position] > random_value ) { upper_bound = position; } else { lower_bound = position; }     
+		( rates[position] > random_value ) ? upper_bound = position : lower_bound = position;     
 		
 		position = ( lower_bound + upper_bound ) / 2;
 	}
@@ -275,10 +355,8 @@ void select_multi_edges( long double rates[], int index_selected_edges[], int *s
 
 		while( upper_bound - lower_bound > 1 )
 		{
-			if ( rates[position] > random_value )    
-				upper_bound = position;    
-			else                                                
-				lower_bound = position;     
+			//if ( rates[position] > random_value ) { upper_bound = position; } else { lower_bound = position; }     
+			( rates[position] > random_value ) ? upper_bound = position : lower_bound = position;     
 			
 			position = ( lower_bound + upper_bound ) / 2;
 		}
@@ -404,7 +482,7 @@ void Hsub_rows_mins( double A[], double sub_A[], int *row, int *col, int *p )
 // sub_matrices1 for Hermitian matrix
 void Hsub_matrices1( double A[], double A12[], double A22[], int *sub, int *p )
 {
-	int i, j, ixpdim, ij, pdim = *p, p1 = pdim - 1, psub = *sub, subxp = psub * pdim, mpsub = pdim - psub - 1;
+	int i, ixpdim, pdim = *p, p1 = pdim - 1, psub = *sub, subxp = psub * pdim, mpsub = pdim - psub - 1;
 
 	for( i = 0; i < psub; i++ )
 		A12[i] = -A[subxp + i];
@@ -414,22 +492,22 @@ void Hsub_matrices1( double A[], double A12[], double A22[], int *sub, int *p )
 	for( i = 0; i < psub; i++ )
 	{	
 		ixpdim = i * pdim;
-		memcpy( A22 + i * p1, A + ixpdim, sizeof( double ) * psub );
+		memcpy( A22 + i * p1       , A + ixpdim           , sizeof( double ) * psub );
 		memcpy( A22 + i * p1 + psub, A + ixpdim + psub + 1, sizeof( double ) * mpsub );
 	}
 
 	for( i = psub + 1; i < pdim; i++ )
 	{
 		ixpdim = i * pdim;
-		memcpy( A22 + ( i - 1 ) * p1, A + ixpdim, sizeof( double ) * psub);
-                memcpy( A22 + ( i - 1 ) * p1 + psub, A + ixpdim + psub + 1, sizeof( double ) * mpsub );
+		memcpy( A22 + ( i - 1 ) * p1       , A + ixpdim           , sizeof( double ) * psub);
+		memcpy( A22 + ( i - 1 ) * p1 + psub, A + ixpdim + psub + 1, sizeof( double ) * mpsub );
 	}
 }
         
 // sub_matrices for Hermitian matrix
 void Hsub_matrices( double A[], double A11[], double A12[], double A22[], int *row, int *col, int *p )
 {
-	int i, i1, i2, j, ixp, ij, pdim = *p, p2 = pdim - 2, sub0 = *row, sub1 = *col;
+	int i, i1, i2, ixp, pdim = *p, p2 = pdim - 2, sub0 = *row, sub1 = *col;
 
 	A11[0] = A[sub0 * pdim + sub0];
 	A11[1] = A[sub0 * pdim + sub1];
@@ -443,8 +521,8 @@ void Hsub_matrices( double A[], double A11[], double A12[], double A22[], int *r
 		A12[i + i]     = A[ixp + sub0];
 		A12[i + i + 1] = A[ixp + sub1];
 
-		memcpy( A22 + i * p2, A + ixp, sizeof( double ) * sub0 );
-		memcpy( A22 + i * p2 + sub0, A + ixp + sub0 + 1, sizeof( double ) * ( sub1 - sub0 - 1 ) );
+		memcpy( A22 + i * p2,            A + ixp,            sizeof( double ) * sub0 );
+		memcpy( A22 + i * p2 + sub0,     A + ixp + sub0 + 1, sizeof( double ) * ( sub1 - sub0 - 1 ) );
 		memcpy( A22 + i * p2 + sub1 - 1, A + ixp + sub1 + 1, sizeof( double ) * ( pdim - sub1 - 1 ) );	
 	}
  
@@ -456,21 +534,21 @@ void Hsub_matrices( double A[], double A11[], double A12[], double A22[], int *r
 		A12[i + i - 2] = A[ixp + sub0];
 		A12[i + i - 1] = A[ixp + sub1];
 
-		memcpy( A22 + i1 * p2, A + ixp, sizeof( double ) * sub0 );
-		memcpy( A22 + i1 * p2 + sub0, A + ixp + sub0 + 1, sizeof( double ) * ( sub1 - sub0 - 1 ) );
+		memcpy( A22 + i1 * p2,            A + ixp,            sizeof( double ) * sub0 );
+		memcpy( A22 + i1 * p2 + sub0,     A + ixp + sub0 + 1, sizeof( double ) * ( sub1 - sub0 - 1 ) );
 		memcpy( A22 + i1 * p2 + sub1 - 1, A + ixp + sub1 + 1, sizeof( double ) * ( pdim - sub1 - 1 ) );	
 	}
 	
 	for( i = sub1 + 1; i < pdim; i++ )
 	{
 		ixp = i * pdim;
-		i2 = i - 2;
+		i2  = i - 2;
 				
-		A12[i + i - 4]     = A[ixp + sub0];
-		A12[i + i - 3]     = A[ixp + sub1];
+		A12[i + i - 4] = A[ixp + sub0];
+		A12[i + i - 3] = A[ixp + sub1];
 
-		memcpy( A22 + i2 * p2, A + ixp, sizeof( double ) * sub0 );
-		memcpy( A22 + i2 * p2 + sub0, A + ixp + sub0 + 1, sizeof( double ) * ( sub1 - sub0 - 1 ) );
+		memcpy( A22 + i2 * p2,            A + ixp,            sizeof( double ) * sub0 );
+		memcpy( A22 + i2 * p2 + sub0,     A + ixp + sub0 + 1, sizeof( double ) * ( sub1 - sub0 - 1 ) );
 		memcpy( A22 + i2 * p2 + sub1 - 1, A + ixp + sub1 + 1, sizeof( double ) * ( pdim - sub1 - 1 ) );		
 	}
 }
